<?php

/*  Options framework */
if ( !function_exists( 'optionsframework_init' ) ) {
	define( 'OPTIONS_FRAMEWORK_DIRECTORY', get_template_directory_uri() . '/admin/' );
	require_once dirname( __FILE__ ) . '/admin/options-framework.php';
}

/* Including custom widget */
include(get_template_directory() . '/inc/awanlangit-social-button.php');

/* add_action() section */
add_action('admin_init',        'awanlangit_change_santiziation', 100);
add_action('after_setup_theme', 'awanlangit_setup' );
add_action('after_setup_theme', 'awanlangit_translate' );
add_action('widgets_init',      'awanlangit_widgets_init' );
add_action('wp_head',           'awanlangit_custom_favicon', 5);
add_action('wp_head',           'awanlangit_custom_css', 10);
add_action('wp_head',           'awanlangit_meta_google', 2);
add_action('wp_head',           'awanlangit_meta_alexa', 2);
add_action('wp_head',           'awanlangit_meta_bing', 2);
add_action('wp_head',           'awanlangit_scripts' );
add_action('wp_footer',         'awanlangit_analytics');

/* add_filter() section */
add_filter('use_default_gallery_style', '__return_false' );
add_filter('excerpt_length',  'awanlangit_excerpt_length' );
add_filter('excerpt_more',    'awanlangit_auto_excerpt_more' );
add_filter('get_the_excerpt', 'awanlangit_custom_excerpt_more' );
add_filter('wp_title',        'awanlangit_filter_title');
add_filter('the_title',       'awanlangit_untitled');

/* Sets up theme defaults and registers support for various WordPress features */

function awanlangit_setup() {
    
    /* Set the content width */
    if ( ! isset( $content_width ) ) 
    $content_width = 598; /* pixels */

	/* enable the editor style */
	add_editor_style();
		
	/* automatic posts and comment RSS link in the head */
	add_theme_support( 'automatic-feed-links' );
	
	/* custom background support */
	add_theme_support( 'custom-background' );
    
	/* enable post thumbnail support */
	add_theme_support( 'post-thumbnails' );
	add_image_size('post-thumbnail', 520, 150, true);
	
	/* register the nav menu */
   	register_nav_menus(
  		array(
		  'awanlangit'        => __( 'awanlangit Navigation Menu','awanlangit' ),
		  'awanlangit_footer' => __( 'awanlangit Footer Menu','awanlangit' )
  		)
   	);
	
	/* Remove unnecessary stuffs from head	*/
	remove_action('wp_head', 'rsd_link');
	remove_action('wp_head', 'wp_generator');
	remove_action('wp_head', 'index_rel_link');
	remove_action('wp_head', 'wlwmanifest_link');
	remove_action('wp_head', 'feed_links_extra', 3);
	remove_action('wp_head', 'start_post_rel_link', 10, 0);
	remove_action('wp_head', 'parent_post_rel_link', 10, 0);
	remove_action('wp_head', 'adjacent_posts_rel_link', 10, 0);
}

/* Register widgetisize area */

function awanlangit_widgets_init() {
register_sidebar(array(
    'id'            => 'sidebar-1',
    'name'          => __('Left Sidebar', 'awanlangit'),
    'description'   => __('Left Sidebar in awanlangit themes', 'awanlangit'),
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget'  => '</div>',
    'before_title'  => '<h4>',
    'after_title'   => '</h4>',
    ));
register_sidebar(array(
    'id'            => 'sidebar-2',
    'name'          => __('Middle Sidebar', 'awanlangit'),
    'description'   => __('Middle Sidebar in awanlangit themes', 'awanlangit'),
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget'  => '</div>',
    'before_title'  => '<h4>',
    'after_title'   => '</h4>',
    ));
register_sidebar(array(
    'id'            => 'sidebar-3',
    'name'          => __('Right Sidebar', 'awanlangit'),
    'description'   => __('Right Sidebar in awanlangit themes', 'awanlangit'),
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget'  => '</div>',
    'before_title'  => '<h4>',
    'after_title'   => '</h4>',
    ));
}

/* Add theme language */
function awanlangit_translate(){
   load_theme_textdomain( 'awanlangit', get_template_directory() . '/languages' );

	$locale = get_locale();
	$locale_file = get_template_directory() . "/languages/$locale.php";
	if ( is_readable( $locale_file ) )
		require_once( $locale_file );
}
  
/* Custom Excerpt function */
function awanlangit_excerpt_length( $length ) {
	return 40;
}

function awanlangit_continue_reading_link() {
	return ' <a href="'. esc_url( get_permalink() ) . '">' . __( 'Continue reading &rarr;', 'awanlangit' ) . '</a>';
}

function awanlangit_auto_excerpt_more( $more ) {
	return ' &hellip;' . awanlangit_continue_reading_link();
}

function awanlangit_custom_excerpt_more( $output ) {
	if ( has_excerpt() && ! is_attachment() ) {
		$output .= ' &hellip;'  . awanlangit_continue_reading_link();
	}
	return $output;
}

/* Default menu fallback function */
function awanlangit_default_menu() {
	echo '<nav id="main-nav"><ul class="sf-menu"><li><a href="#">Home</a></li></ul></nav>';
}

/* Content navigation */
function blackzebra_content_nav() {
	global $wp_query;

	$paged			=	( get_query_var( 'paged' ) ) ? intval( get_query_var( 'paged' ) ) : 1;
	$pagenum_link	=	get_pagenum_link();
	$url_parts		=	parse_url( $pagenum_link );
	$format			=	( get_option('permalink_structure') ) ? user_trailingslashit('page/%#%', 'paged') : '?paged=%#%';
	
	if ( isset($url_parts['query']) ) {
		$pagenum_link	=	"{$url_parts['scheme']}://{$url_parts['host']}{$url_parts['path']}%_%?{$url_parts['query']}";
	} else {
		$pagenum_link	.=	'%_%';
	}
	
	$links	=	paginate_links( array(
		'base'		=>	$pagenum_link,
		'format'	=>	$format,
		'total'		=>	$wp_query->max_num_pages,
		'current'	=>	$paged,
		'mid_size'	=>	2,
		'type'		=>	'list'
	) );
	
	if (!is_single() && $links ) {
		echo "<div id=\"page-nav\" class=\"wide\">{$links}</div><div class=\"clearfix\"></div>";
	}
	if (is_single()){		
		wp_link_pages( array( 'before' => '<div id="post-pages" class="wide"><span>' . __( 'Pages:', 'awanlangit' ) . '</span>', 'after' => '</div><div class="clearfix"></div>' ) );
		
		echo '<div id="page-nav" class="wide">';
			next_post_link('<span class="next-post">%link</span>', '&larr; %title');
			previous_post_link('<span class="prev-post">%link</span>', '%title &rarr;');
		echo '</div><div class="clearfix"></div>';
	}
}

/* Title filter by wp_title() */
function awanlangit_filter_title( $filter_title ){
	global $page, $paged;

	$filter_title = str_replace( '&raquo;', '', $filter_title );
	$site_description = get_bloginfo( 'description', 'display' );
	$separator = '#124';
	
	if ( is_singular() ) {
		if ( $paged >= 2 || $page >= 2 )$filter_title .=  ', ' . __( 'Page', 'awanlangit' ) . ' ' . max( $paged, $page );
	} else {
		if( ! is_home() )$filter_title .= ' &' . $separator . '; ';
		$filter_title .= get_bloginfo( 'name' );
		
		if ( $paged >= 2 || $page >= 2 )
			$filter_title .=  ', ' . __( 'Page', 'awanlangit' ) . ' ' . max( $paged, $page );
	}

	if ( is_home() && $site_description )
		$filter_title .= ' &' . $separator . '; ' . $site_description;

	return $filter_title;
}

/*  Filter content with empty post title */
function awanlangit_untitled($title) {
	if ($title == '') {
		return __('Untitled', 'awanlangit');
	} else {
		return $title;
	}
}  

/* Comment and trackback layout */
function blackzebra_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'awanlangit' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( '(Edit)', 'awanlangit' ), ' ' ); ?></p>
	<?php
			break;
		default :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>">
			<div class="comment-avatar"><?php echo get_avatar( $comment, 40 ); ?></div>
			
			<div class="comment-block">
			<div class="comment-meta">
				<span class="comment-author fn"><?php echo get_comment_author_link(); ?></span>
				<span class="comment-date"><a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
				<?php printf( __( '&middot; %1$s at %2$s &middot;', 'awanlangit' ), get_comment_date(), get_comment_time() ); ?>
				</a></span>
				<?php edit_comment_link( __( '(Edit)', 'awanlangit' ), ' ' );	?>
			<?php if ( $comment->comment_approved == '0' ) : ?>
				<em><?php _e( 'Your comment is awaiting moderation.', 'awanlangit' ); ?></em>
				<br />
			<?php endif; ?>
			</div>
			<div class="comment-content"><?php comment_text(); ?></div>

			<div class="reply">
				<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</div><!-- .reply -->
			</div>
		</article><!-- #comment-## -->

	<?php
			break;
	endswitch;
}
  
/* Enqueue scripts and styles */
function awanlangit_scripts() {
    wp_enqueue_style( 'style', get_template_directory_uri() . '/style.css', false, '1.0', 'all' );
    
	wp_enqueue_script( 'jquery-1.7.2.min.js', get_template_directory_uri() . '/js/jquery-1.7.2.min.js', array( 'jquery' ), '1.7.2', true );
	wp_enqueue_script( 'easing.js', get_template_directory_uri() . '/js/easing.js', array( 'jquery' ), '0.1', true );
    wp_enqueue_script( 'jquery.ui.totop', get_template_directory_uri() . '/js/jquery.ui.totop.js', array( 'jquery' ), '0.1', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

}
  
/* Output themes options */

/* Output favicon from theme options */
function awanlangit_custom_favicon() {
	if (of_get_option('awanlangit_custom_favicon'))
		echo '<link rel="shortcut icon" href="'. esc_url( of_get_option('awanlangit_custom_favicon') ) .'">'."\n";
}

/* Output Custom CSS from theme options */
function awanlangit_custom_css() {
	$custom_css = of_get_option('awanlangit_custom_css');
	
	if ($custom_css != '') {
		echo "<!-- Custom Styling -->\n<style type=\"text/css\">\n" . esc_attr( $custom_css ) . "\n</style>\n";
	}
}

/* Output Google meta verification from theme options */
function awanlangit_meta_google(){
	$output = of_get_option('awanlangit_meta_google');
	if ( $output ) 
		echo '<meta name="google-site-verification" content="' . esc_attr( $output ) . '"> ' . "\n";
}

/* Output Alexa meta verification from theme options */
function awanlangit_meta_alexa(){
	$output = of_get_option('awanlangit_meta_alexa');
	if ( $output ) 
		echo '<meta name="alexaVerifyID" content="' . esc_attr( $output ) . '"> ' . "\n";
}

/* Output Bing meta verification from theme options */
function awanlangit_meta_bing(){
	$output = of_get_option('awanlangit_meta_bing');
	if ( $output ) 
		echo '<meta name="msvalidate.01" content="' . esc_attr( $output ) . '"> ' . "\n";
}

/* Output analytics code in footer from theme options */
function awanlangit_analytics(){
	$output = of_get_option('awanlangit_analytic_code');
	if ( $output ) 
		echo "<div class='analytic_code'>\n" . stripslashes($output) . "\n</div>";
}

/* textarea sanitization and $allowedposttags + embed and script
 * based on theme options framework */
function awanlangit_change_santiziation() {
    remove_filter( 'of_sanitize_textarea', 'of_sanitize_textarea' );
    add_filter( 'of_sanitize_textarea', 'awanlangit_sanitize_textarea' );
}

function awanlangit_sanitize_textarea($input) {
    global $allowedposttags;
    $custom_allowedtags["embed"] = array(
		"src"               => array(),
		"type"              => array(),
		"allowfullscreen"   => array(),
		"allowscriptaccess" => array(),
		"height"            => array(),
		"width"             => array()
		);
	$custom_allowedtags["script"] = array();
	$custom_allowedtags = array_merge($custom_allowedtags, $allowedposttags);
	$output = wp_kses( $input, $custom_allowedtags);
    return $output;
}

?>